#
# Makefile for Little Smalltalk, version 2
#
CFLAGS = -g

COMMONc = memory.c names.c lex.c parser.c
COMMONo = memory.o names.o lex.o parser.o
PARSEc  = comp.c $(COMMONc) image.c
PARSEo  = comp.o $(COMMONo) image.o
STc     = main.c $(COMMONc) process.c primitive.c interp.c
STo     = main.o $(COMMONo) process.o primitive.o interp.o
classes = basic.st unix.st mult.st unix2.st test.st
allfiles = READ_ME Bugs Makefile todo *.ms *.h *.c *.st testscript

install: parse st test sunix
	echo "created single process version, see docs for more info"

#
# parse - the object image parser.  
# used to build the initial object image
#
parse: $(PARSEo)
	cc -o parse $(CFLAGS) $(PARSEo)

parseprint:
	pr *.h $(PARSEc) | lpr

parselint:
	lint $(PARSEc)

#
# st - the actual bytecode interpreter
# runs bytecodes from the initial image, or another image
#
st: $(STo)
	cc $(CFLAGS) -o st $(STo) -lm

stlint: 
	lint $(STc)

stprint:
	pr *.h $(STc) | lpr

report: memory.o report.o
	cc -o report memory.o report.o

#
# image - build the initial object image
#
classlpr:
	pr $(classes) | lpr

sunix: parse 
	parse basic.st unix.st

munix: parse
	parse basic.st mult.st unix2.st

stest: parse
	parse basic.st unix.st test.st

mtest: parse
	parse basic.st mult.st unix2.st test.st

#
# test - a simple test script
#

test: stest
	echo running test script
	st <testscript

#
# distribution bundles
#

tar:
	tar cvf ../smalltalk.v2.tar .
	compress -c ../smalltalk.v2.tar >../smalltalk.v2.tar.Z

pack:
	packmail -h'head' $(allfiles)
